/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03050
 |            UNIFORM FACILITY DATA SET, 1998: [UNITED STATES]
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03050-0001-statasetup.do)
 |
 **************************************************************************/

set mem 20m  /* Allocating 20 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Uniform Facility Data Set, 1998:  [United States]"

#delimit ;
label define MODE      -9 "MISSING" 1 "Telephone" 2 "Mail survey" ;
label define STFIPS    -9 "MISSING" 1 "ALABAMA" 2 "ALASKA" 3 "ARKANSAS"
                       4 "ARIZONA" 5 "ARKANSAS" 6 "CALIFORNIA"
                       7 "CONNECTICUT" 8 "COLORADO" 9 "CONNECTICUT"
                       10 "DELAWARE" 11 "DIST OF COLUMBIA" 12 "FLORIDA"
                       13 "GEORGIA" 14 "IDAHO" 15 "HAWAII" 16 "IDAHO"
                       17 "ILLINOIS" 18 "INDIANA" 19 "IOWA" 20 "KANSAS"
                       21 "KENTUCKY" 22 "LOUISIANA" 23 "MAINE" 24 "MARYLAND"
                       25 "MASSACHUSETTS" 26 "MICHIGAN" 27 "MINNESOTA"
                       28 "MISSISSIPPI" 29 "MISSOURI" 30 "MONTANA"
                       31 "NEBRASKA" 32 "NEVADA" 33 "NEW HAMPSHIRE"
                       34 "NEW JERSEY" 35 "NEW MEXICO" 36 "NEW YORK"
                       37 "NORTH CAROLINA" 38 "NORTH DAKOTA" 39 "OHIO"
                       40 "OKLAHOMA" 41 "OREGON" 42 "PENNSYLVANIA"
                       43 "SOUTH DAKOTA" 44 "RHODE ISLAND"
                       45 "SOUTH CAROLINA" 46 "SOUTH DAKOTA" 47 "TENNESSEE"
                       48 "TEXAS" 49 "UTAH" 50 "VERMONT" 51 "VIRGINIA"
                       52 "WYOMING" 53 "WASHINGTON" 54 "WEST VIRGINIA"
                       55 "WISCONSIN" 56 "WYOMING" 57 "VIRGIN ISLANDS"
                       60 "AMERICAN SAMOA" 64 "FED MICRONESIA" 66 "GUAM"
                       70 "PALAU" 72 "PUERTO RICO" 78 "VIRGIN ISLANDS" ;
label define TREATMT   -9 "MISSING" 1 "Yes" 2 "No" ;
label define DETOX     -9 "MISSING" 1 "Yes" 2 "No" ;
label define PREVNTN   -9 "MISSING" 1 "Yes" 2 "No" ;
label define OTHNONTX  -9 "MISSING" 1 "Yes" 2 "No" ;
label define OWNERSHP  -9 "MISSING" 1 "A private-for-profit organization"
                       2 "A private non-profit organization"
                       3 "State government"
                       4 "Local, county or community government"
                       5 "Tribal government" 6 "Federal government" ;
label define FEDOWN    -9 "MISSING" 1 "Department of Veterans Affairs"
                       2 "Department of Defense" 3 "Bureau of prisons"
                       4 "Indian Health Service" 5 "Other" ;
label define LOC1      -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC2      -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC3      -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC4      -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC5      -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC6      -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC7      -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC8      -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC9      -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC10     -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC11     -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC12     -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC13     -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC14     -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC15     -9 "MISSING" 1 "Yes" 2 "No" ;
label define LOC16     -9 "MISSING" 1 "Yes" 2 "No" ;
label define MGMCARE   -9 "MISSING" 1 "Yes" 2 "No" ;
label define WRITARRA  -9 "MISSING" 1 "Yes" 2 "No" 3 "Don't know" ;
label define WRITNUM   -9 "MISSING" ;
label define OWNER     -9 "MISSING" 1 "Private non-profit"
                       2 "Private for profit" 3 "Local, community government"
                       4 "State Government" 5 "Federal Government"
                       6 "Tribal Government" ;
label define SETTING   -9 "MISSING" 1 "Outpatient" 2 "Residential"
                       3 "Outpatient and residential"
                       4 "Community Mental Health Center"
                       5 "Solo / Group practice" 6 "General Hospital"
                       7 "Psych Hospital" 8 "Criminal Justice"
                       9 "Community and religious" 10 "Health Center"
                       11 "Mixed / Other" ;
label define ADMIN     -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC1     -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC2     -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC3     -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC4     -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC5     -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC6     -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC7     -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC8     -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC9     -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC10    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC11    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC12    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC13    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC14    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC15    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC16    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC17    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC18    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC19    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC20    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC21    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC22    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC23    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC24    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC25    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC26    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC27    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC28    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC29    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC36    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC37    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC38    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC39    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC40    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC41    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC42    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC43    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC44    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC45    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC46    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC47    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC48    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC49    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC50    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC51    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC52    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC53    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC54    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC55    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC56    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC57    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC58    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC59    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC60    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC30    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC31    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC32    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC33    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC34    -9 "MISSING" 1 "Yes" 2 "No" ;
label define SRVC35    -9 "MISSING" 1 "Yes" 2 "No" ;
label define TYPE1     -9 "MISSING" 1 "Yes" 2 "No" ;
label define TYPE2     -9 "MISSING" 1 "Yes" 2 "No" ;
label define TYPE3     -9 "MISSING" 1 "Yes" 2 "No" ;
label define TYPE4     -9 "MISSING" 1 "Yes" 2 "No" ;
label define TYPE5     -9 "MISSING" 1 "Yes" 2 "No" ;
label define TYPE6     -9 "MISSING" 1 "Yes" 2 "No" ;
label define TYPE7     -9 "MISSING" 1 "Yes" 2 "No" ;
label define ADMINLNK  -9 "MISSING" 1 "Yes" 2 "No" ;
label define FACNUM    -9 "MISSING" ;
label define OTHFAC1   -9 "MISSING" 1 "Yes" 2 "No" ;
label define OTHFAC2   -9 "MISSING" 1 "Yes" 2 "No" ;
label define OTHFAC3   -9 "MISSING" 1 "Yes" 2 "No" ;
label define CLIENTS4  -9 "MISSING" ;
label define HISVC     -9 "MISSING" 1 "Yes" 2 "No" ;
label define HOSPBED   -9 "MISSING" ;
label define T_CLI1    -9 "MISSING" ;
label define T_CLI2    -9 "MISSING" ;
label define T_CLIHI   -9 "MISSING" ;
label define HIMETLAM  -9 "MISSING" 1 "Does not dispense" 2 "Does dispense" ;
label define HIMETNUM  -9 "MISSING" ;
label define HILAMNUM  -9 "MISSING" ;
label define H_SEX1    -9 "MISSING" ;
label define H_SEX2    -9 "MISSING" ;
label define H_SEX3    -9 "MISSING" ;
label define H_SEX4    -9 "MISSING" ;
label define H_RE1     -9 "MISSING" ;
label define H_RE2     -9 "MISSING" ;
label define H_RE3     -9 "MISSING" ;
label define H_RE4     -9 "MISSING" ;
label define H_RE5     -9 "MISSING" ;
label define H_RE6     -9 "MISSING" ;
label define H_RE7     -9 "MISSING" ;
label define H_RE8     -9 "MISSING" ;
label define H_AGE1    -9 "MISSING" ;
label define H_AGE2    -9 "MISSING" ;
label define H_AGE3    -9 "MISSING" ;
label define H_AGE4    -9 "MISSING" ;
label define H_AGE5    -9 "MISSING" ;
label define H_AGE6    -9 "MISSING" ;
label define H_AGE7    -9 "MISSING" ;
label define H_AGE8    -9 "MISSING" ;
label define H_AGE9    -9 "MISSING" ;
label define RCSVC     -9 "MISSING" 1 "Yes" 2 "No" ;
label define RESBED    -9 "MISSING" ;
label define T_CLI3    -9 "MISSING" ;
label define T_CLI4    -9 "MISSING" ;
label define T_CLIRC   -9 "MISSING" ;
label define RCMETLAM  -9 "MISSING" 1 "Does not dispense" 2 "Does dispense" ;
label define RCMETNUM  -9 "MISSING" ;
label define RCLAMNUM  -9 "MISSING" ;
label define R_SEX1    -9 "MISSING" ;
label define R_SEX2    -9 "MISSING" ;
label define R_SEX3    -9 "MISSING" ;
label define R_SEX4    -9 "MISSING" ;
label define R_RE1     -9 "MISSING" ;
label define R_RE2     -9 "MISSING" ;
label define R_RE3     -9 "MISSING" ;
label define R_RE4     -9 "MISSING" ;
label define R_RE5     -9 "MISSING" ;
label define R_RE6     -9 "MISSING" ;
label define R_RE7     -9 "MISSING" ;
label define R_RE8     -9 "MISSING" ;
label define R_AGE1    -9 "MISSING" ;
label define R_AGE2    -9 "MISSING" ;
label define R_AGE3    -9 "MISSING" ;
label define R_AGE4    -9 "MISSING" ;
label define R_AGE5    -9 "MISSING" ;
label define R_AGE6    -9 "MISSING" ;
label define R_AGE7    -9 "MISSING" ;
label define R_AGE8    -9 "MISSING" ;
label define R_AGE9    -9 "MISSING" ;
label define OUTSVC    -9 "MISSING" 1 "Yes" 2 "No" ;
label define T_CLI7    -9 "MISSING" ;
label define T_CLI6    -9 "MISSING" ;
label define T_CLI5    -9 "MISSING" ;
label define T_CLIOP   -9 "MISSING" ;
label define OPMETLAM  -9 "MISSING" 1 "Does not dispense" 2 "Does dispense" ;
label define OPMETNUM  -9 "MISSING" ;
label define OPLAMNUM  -9 "MISSING" ;
label define O_SEX1    -9 "MISSING" ;
label define O_SEX2    -9 "MISSING" ;
label define O_SEX3    -9 "MISSING" ;
label define O_SEX4    -9 "MISSING" ;
label define O_RE1     -9 "MISSING" ;
label define O_RE2     -9 "MISSING" ;
label define O_RE3     -9 "MISSING" ;
label define O_RE4     -9 "MISSING" ;
label define O_RE5     -9 "MISSING" ;
label define O_RE6     -9 "MISSING" ;
label define O_RE7     -9 "MISSING" ;
label define O_RE8     -9 "MISSING" ;
label define O_AGE1    -9 "MISSING" ;
label define O_AGE2    -9 "MISSING" ;
label define O_AGE3    -9 "MISSING" ;
label define O_AGE4    -9 "MISSING" ;
label define O_AGE5    -9 "MISSING" ;
label define O_AGE6    -9 "MISSING" ;
label define O_AGE7    -9 "MISSING" ;
label define O_AGE8    -9 "MISSING" ;
label define O_AGE9    -9 "MISSING" ;
label define TOTADMIS  -9 "MISSING" ;
label define SACL98    -9 "MISSING" 1 "Yes" 2 "No" ;
label define B_PCT     -9 "MISSING" ;
label define A_PCT     -9 "MISSING" ;
label define D_PCT     -9 "MISSING" ;
label define INJPCT    -9 "MISSING" ;
label define TBPCT     -9 "MISSING" ;
label define HIVPCT    -9 "MISSING" ;
label define PREVPCT   -9 "MISSING" ;
label define MGDPCT    -9 "MISSING" ;
label define CTPCT     -9 "MISSING" ;
label define PREGPCT   -9 "MISSING" ;
label define DEPPCT    -9 "MISSING" ;
label define OPMLTOTL  -9 "MISSING" ;
label define HIMLTOTL  -9 "MISSING" ;
label define RCMLTOTL  -9 "MISSING" ;
label define MALE      -9 "MISSING" ;
label define FEMALE    -9 "MISSING" ;
label define UNKNOWN   -9 "MISSING" ;
label define TTLGNDR   -9 "MISSING" ;
label define WHITE     -9 "MISSING" ;
label define BLACK     -9 "MISSING" ;
label define HISPANIC  -9 "MISSING" ;
label define ASIAN     -9 "MISSING" ;
label define AMERINDN  -9 "MISSING" ;
label define OTHER     -9 "MISSING" ;
label define UNKRACE   -9 "MISSING" ;
label define TTLRACE   -9 "MISSING" ;
label define UNDER18   -9 "MISSING" ;
label define X18_20    -9 "MISSING" ;
label define X21_24    -9 "MISSING" ;
label define X25_34    -9 "MISSING" ;
label define X35_44    -9 "MISSING" ;
label define X45_64    -9 "MISSING" ;
label define OVER65    -9 "MISSING" ;
label define UNKAGE    -9 "MISSING" ;
label define TTLAGE    -9 "MISSING" ;
label define H_SEX1FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_SEX2FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_SEX3FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_SEX4FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_RE1FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_RE2FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_RE3FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_RE4FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_RE5FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_RE6FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_RE7FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_RE8FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_AGE1FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_AGE2FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_AGE3FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_AGE4FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_AGE5FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_AGE6FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_AGE7FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_AGE8FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define H_AGE9FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_SEX1FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_SEX2FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_SEX3FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_SEX4FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_RE1FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_RE2FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_RE3FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_RE4FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_RE5FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_RE6FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_RE7FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_RE8FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_AGE1FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_AGE2FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_AGE3FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_AGE4FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_AGE5FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_AGE6FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_AGE7FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_AGE8FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define O_AGE9FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_SEX1FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_SEX2FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_SEX3FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_SEX4FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_RE1FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_RE2FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_RE3FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_RE4FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_RE5FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_RE6FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_RE7FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_RE8FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_AGE1FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_AGE2FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_AGE3FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_AGE4FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_AGE5FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_AGE6FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_AGE7FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_AGE8FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define R_AGE9FL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define TCLI1FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define TCLI2FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define TCLI3FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define TCLI4FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define TCLI5FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define TCLI6FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define TCLI7FL   -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define TCLIRCFL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define TCLIOPFL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;
label define TCLIHIFL  -9 "MISSING" 0 "Value not imputed" 1 "Value Imputed"
                       2 "Value not imputed/not used in imputation" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace MODE = . if (MODE <= -1 )
replace STFIPS = . if (STFIPS <= -1 )
replace TREATMT = . if (TREATMT <= -1 )
replace DETOX = . if (DETOX <= -1 )
replace PREVNTN = . if (PREVNTN <= -1 )
replace OTHNONTX = . if (OTHNONTX <= -1 )
replace OWNERSHP = . if (OWNERSHP <= -1 )
replace FEDOWN = . if (FEDOWN <= -1 )
replace LOC1 = . if (LOC1 <= -1 )
replace LOC2 = . if (LOC2 <= -1 )
replace LOC3 = . if (LOC3 <= -1 )
replace LOC4 = . if (LOC4 <= -1 )
replace LOC5 = . if (LOC5 <= -1 )
replace LOC6 = . if (LOC6 <= -1 )
replace LOC7 = . if (LOC7 <= -1 )
replace LOC8 = . if (LOC8 <= -1 )
replace LOC9 = . if (LOC9 <= -1 )
replace LOC10 = . if (LOC10 <= -1 )
replace LOC11 = . if (LOC11 <= -1 )
replace LOC12 = . if (LOC12 <= -1 )
replace LOC13 = . if (LOC13 <= -1 )
replace LOC14 = . if (LOC14 <= -1 )
replace LOC15 = . if (LOC15 <= -1 )
replace LOC16 = . if (LOC16 <= -1 )
replace MGMCARE = . if (MGMCARE <= -1 )
replace WRITARRA = . if (WRITARRA <= -1 )
replace WRITNUM = . if (WRITNUM <= -1 )
replace OWNER = . if (OWNER <= -1 )
replace SETTING = . if (SETTING <= -1 )
replace ADMIN = . if (ADMIN <= -1 )
replace SRVC1 = . if (SRVC1 <= -1 )
replace SRVC2 = . if (SRVC2 <= -1 )
replace SRVC3 = . if (SRVC3 <= -1 )
replace SRVC4 = . if (SRVC4 <= -1 )
replace SRVC5 = . if (SRVC5 <= -1 )
replace SRVC6 = . if (SRVC6 <= -1 )
replace SRVC7 = . if (SRVC7 <= -1 )
replace SRVC8 = . if (SRVC8 <= -1 )
replace SRVC9 = . if (SRVC9 <= -1 )
replace SRVC10 = . if (SRVC10 <= -1 )
replace SRVC11 = . if (SRVC11 <= -1 )
replace SRVC12 = . if (SRVC12 <= -1 )
replace SRVC13 = . if (SRVC13 <= -1 )
replace SRVC14 = . if (SRVC14 <= -1 )
replace SRVC15 = . if (SRVC15 <= -1 )
replace SRVC16 = . if (SRVC16 <= -1 )
replace SRVC17 = . if (SRVC17 <= -1 )
replace SRVC18 = . if (SRVC18 <= -1 )
replace SRVC19 = . if (SRVC19 <= -1 )
replace SRVC20 = . if (SRVC20 <= -1 )
replace SRVC21 = . if (SRVC21 <= -1 )
replace SRVC22 = . if (SRVC22 <= -1 )
replace SRVC23 = . if (SRVC23 <= -1 )
replace SRVC24 = . if (SRVC24 <= -1 )
replace SRVC25 = . if (SRVC25 <= -1 )
replace SRVC26 = . if (SRVC26 <= -1 )
replace SRVC27 = . if (SRVC27 <= -1 )
replace SRVC28 = . if (SRVC28 <= -1 )
replace SRVC29 = . if (SRVC29 <= -1 )
replace SRVC36 = . if (SRVC36 <= -1 )
replace SRVC37 = . if (SRVC37 <= -1 )
replace SRVC38 = . if (SRVC38 <= -1 )
replace SRVC39 = . if (SRVC39 <= -1 )
replace SRVC40 = . if (SRVC40 <= -1 )
replace SRVC41 = . if (SRVC41 <= -1 )
replace SRVC42 = . if (SRVC42 <= -1 )
replace SRVC43 = . if (SRVC43 <= -1 )
replace SRVC44 = . if (SRVC44 <= -1 )
replace SRVC45 = . if (SRVC45 <= -1 )
replace SRVC46 = . if (SRVC46 <= -1 )
replace SRVC47 = . if (SRVC47 <= -1 )
replace SRVC48 = . if (SRVC48 <= -1 )
replace SRVC49 = . if (SRVC49 <= -1 )
replace SRVC50 = . if (SRVC50 <= -1 )
replace SRVC51 = . if (SRVC51 <= -1 )
replace SRVC52 = . if (SRVC52 <= -1 )
replace SRVC53 = . if (SRVC53 <= -1 )
replace SRVC54 = . if (SRVC54 <= -1 )
replace SRVC55 = . if (SRVC55 <= -1 )
replace SRVC56 = . if (SRVC56 <= -1 )
replace SRVC57 = . if (SRVC57 <= -1 )
replace SRVC58 = . if (SRVC58 <= -1 )
replace SRVC59 = . if (SRVC59 <= -1 )
replace SRVC60 = . if (SRVC60 <= -1 )
replace SRVC30 = . if (SRVC30 <= -1 )
replace SRVC31 = . if (SRVC31 <= -1 )
replace SRVC32 = . if (SRVC32 <= -1 )
replace SRVC33 = . if (SRVC33 <= -1 )
replace SRVC34 = . if (SRVC34 <= -1 )
replace SRVC35 = . if (SRVC35 <= -1 )
replace TYPE1 = . if (TYPE1 <= -1 )
replace TYPE2 = . if (TYPE2 <= -1 )
replace TYPE3 = . if (TYPE3 <= -1 )
replace TYPE4 = . if (TYPE4 <= -1 )
replace TYPE5 = . if (TYPE5 <= -1 )
replace TYPE6 = . if (TYPE6 <= -1 )
replace TYPE7 = . if (TYPE7 <= -1 )
replace ADMINLNK = . if (ADMINLNK <= -1 )
replace FACNUM = . if (FACNUM <= -1 )
replace OTHFAC1 = . if (OTHFAC1 <= -1 )
replace OTHFAC2 = . if (OTHFAC2 <= -1 )
replace OTHFAC3 = . if (OTHFAC3 <= -1 )
replace CLIENTS4 = . if (CLIENTS4 <= -1 )
replace HISVC = . if (HISVC <= -1 )
replace HOSPBED = . if (HOSPBED <= -1 )
replace T_CLI1 = . if (T_CLI1 <= -1 )
replace T_CLI2 = . if (T_CLI2 <= -1 )
replace T_CLIHI = . if (T_CLIHI <= -1 )
replace HIMETLAM = . if (HIMETLAM <= -1 )
replace HIMETNUM = . if (HIMETNUM <= -1 )
replace HILAMNUM = . if (HILAMNUM <= -1 )
replace H_SEX1 = . if (H_SEX1 <= -1 )
replace H_SEX2 = . if (H_SEX2 <= -1 )
replace H_SEX3 = . if (H_SEX3 <= -1 )
replace H_SEX4 = . if (H_SEX4 <= -1 )
replace H_RE1 = . if (H_RE1 <= -1 )
replace H_RE2 = . if (H_RE2 <= -1 )
replace H_RE3 = . if (H_RE3 <= -1 )
replace H_RE4 = . if (H_RE4 <= -1 )
replace H_RE5 = . if (H_RE5 <= -1 )
replace H_RE6 = . if (H_RE6 <= -1 )
replace H_RE7 = . if (H_RE7 <= -1 )
replace H_RE8 = . if (H_RE8 <= -1 )
replace H_AGE1 = . if (H_AGE1 <= -1 )
replace H_AGE2 = . if (H_AGE2 <= -1 )
replace H_AGE3 = . if (H_AGE3 <= -1 )
replace H_AGE4 = . if (H_AGE4 <= -1 )
replace H_AGE5 = . if (H_AGE5 <= -1 )
replace H_AGE6 = . if (H_AGE6 <= -1 )
replace H_AGE7 = . if (H_AGE7 <= -1 )
replace H_AGE8 = . if (H_AGE8 <= -1 )
replace H_AGE9 = . if (H_AGE9 <= -1 )
replace RCSVC = . if (RCSVC <= -1 )
replace RESBED = . if (RESBED <= -1 )
replace T_CLI3 = . if (T_CLI3 <= -1 )
replace T_CLI4 = . if (T_CLI4 <= -1 )
replace T_CLIRC = . if (T_CLIRC <= -1 )
replace RCMETLAM = . if (RCMETLAM <= -1 )
replace RCMETNUM = . if (RCMETNUM <= -1 )
replace RCLAMNUM = . if (RCLAMNUM <= -1 )
replace R_SEX1 = . if (R_SEX1 <= -1 )
replace R_SEX2 = . if (R_SEX2 <= -1 )
replace R_SEX3 = . if (R_SEX3 <= -1 )
replace R_SEX4 = . if (R_SEX4 <= -1 )
replace R_RE1 = . if (R_RE1 <= -1 )
replace R_RE2 = . if (R_RE2 <= -1 )
replace R_RE3 = . if (R_RE3 <= -1 )
replace R_RE4 = . if (R_RE4 <= -1 )
replace R_RE5 = . if (R_RE5 <= -1 )
replace R_RE6 = . if (R_RE6 <= -1 )
replace R_RE7 = . if (R_RE7 <= -1 )
replace R_RE8 = . if (R_RE8 <= -1 )
replace R_AGE1 = . if (R_AGE1 <= -1 )
replace R_AGE2 = . if (R_AGE2 <= -1 )
replace R_AGE3 = . if (R_AGE3 <= -1 )
replace R_AGE4 = . if (R_AGE4 <= -1 )
replace R_AGE5 = . if (R_AGE5 <= -1 )
replace R_AGE6 = . if (R_AGE6 <= -1 )
replace R_AGE7 = . if (R_AGE7 <= -1 )
replace R_AGE8 = . if (R_AGE8 <= -1 )
replace R_AGE9 = . if (R_AGE9 <= -1 )
replace OUTSVC = . if (OUTSVC <= -1 )
replace T_CLI7 = . if (T_CLI7 <= -1 )
replace T_CLI6 = . if (T_CLI6 <= -1 )
replace T_CLI5 = . if (T_CLI5 <= -1 )
replace T_CLIOP = . if (T_CLIOP <= -1 )
replace OPMETLAM = . if (OPMETLAM <= -1 )
replace OPMETNUM = . if (OPMETNUM <= -1 )
replace OPLAMNUM = . if (OPLAMNUM <= -1 )
replace O_SEX1 = . if (O_SEX1 <= -1 )
replace O_SEX2 = . if (O_SEX2 <= -1 )
replace O_SEX3 = . if (O_SEX3 <= -1 )
replace O_SEX4 = . if (O_SEX4 <= -1 )
replace O_RE1 = . if (O_RE1 <= -1 )
replace O_RE2 = . if (O_RE2 <= -1 )
replace O_RE3 = . if (O_RE3 <= -1 )
replace O_RE4 = . if (O_RE4 <= -1 )
replace O_RE5 = . if (O_RE5 <= -1 )
replace O_RE6 = . if (O_RE6 <= -1 )
replace O_RE7 = . if (O_RE7 <= -1 )
replace O_RE8 = . if (O_RE8 <= -1 )
replace O_AGE1 = . if (O_AGE1 <= -1 )
replace O_AGE2 = . if (O_AGE2 <= -1 )
replace O_AGE3 = . if (O_AGE3 <= -1 )
replace O_AGE4 = . if (O_AGE4 <= -1 )
replace O_AGE5 = . if (O_AGE5 <= -1 )
replace O_AGE6 = . if (O_AGE6 <= -1 )
replace O_AGE7 = . if (O_AGE7 <= -1 )
replace O_AGE8 = . if (O_AGE8 <= -1 )
replace O_AGE9 = . if (O_AGE9 <= -1 )
replace TOTADMIS = . if (TOTADMIS <= -1 )
replace SACL98 = . if (SACL98 <= -1 )
replace B_PCT = . if (B_PCT <= -1 )
replace A_PCT = . if (A_PCT <= -1 )
replace D_PCT = . if (D_PCT <= -1 )
replace INJPCT = . if (INJPCT <= -1 )
replace TBPCT = . if (TBPCT <= -1 )
replace HIVPCT = . if (HIVPCT <= -1 )
replace PREVPCT = . if (PREVPCT <= -1 )
replace MGDPCT = . if (MGDPCT <= -1 )
replace CTPCT = . if (CTPCT <= -1 )
replace PREGPCT = . if (PREGPCT <= -1 )
replace DEPPCT = . if (DEPPCT <= -1 )
replace OPMLTOTL = . if (OPMLTOTL <= -1 )
replace HIMLTOTL = . if (HIMLTOTL <= -1 )
replace RCMLTOTL = . if (RCMLTOTL <= -1 )
replace MALE = . if (MALE <= -1 )
replace FEMALE = . if (FEMALE <= -1 )
replace UNKNOWN = . if (UNKNOWN <= -1 )
replace TTLGNDR = . if (TTLGNDR <= -1 )
replace WHITE = . if (WHITE <= -1 )
replace BLACK = . if (BLACK <= -1 )
replace HISPANIC = . if (HISPANIC <= -1 )
replace ASIAN = . if (ASIAN <= -1 )
replace AMERINDN = . if (AMERINDN <= -1 )
replace OTHER = . if (OTHER <= -1 )
replace UNKRACE = . if (UNKRACE <= -1 )
replace TTLRACE = . if (TTLRACE <= -1 )
replace UNDER18 = . if (UNDER18 <= -1 )
replace X18_20 = . if (X18_20 <= -1 )
replace X21_24 = . if (X21_24 <= -1 )
replace X25_34 = . if (X25_34 <= -1 )
replace X35_44 = . if (X35_44 <= -1 )
replace X45_64 = . if (X45_64 <= -1 )
replace OVER65 = . if (OVER65 <= -1 )
replace UNKAGE = . if (UNKAGE <= -1 )
replace TTLAGE = . if (TTLAGE <= -1 )
replace H_SEX1FL = . if (H_SEX1FL <= -1 )
replace H_SEX2FL = . if (H_SEX2FL <= -1 )
replace H_SEX3FL = . if (H_SEX3FL <= -1 )
replace H_SEX4FL = . if (H_SEX4FL <= -1 )
replace H_RE1FL = . if (H_RE1FL <= -1 )
replace H_RE2FL = . if (H_RE2FL <= -1 )
replace H_RE3FL = . if (H_RE3FL <= -1 )
replace H_RE4FL = . if (H_RE4FL <= -1 )
replace H_RE5FL = . if (H_RE5FL <= -1 )
replace H_RE6FL = . if (H_RE6FL <= -1 )
replace H_RE7FL = . if (H_RE7FL <= -1 )
replace H_RE8FL = . if (H_RE8FL <= -1 )
replace H_AGE1FL = . if (H_AGE1FL <= -1 )
replace H_AGE2FL = . if (H_AGE2FL <= -1 )
replace H_AGE3FL = . if (H_AGE3FL <= -1 )
replace H_AGE4FL = . if (H_AGE4FL <= -1 )
replace H_AGE5FL = . if (H_AGE5FL <= -1 )
replace H_AGE6FL = . if (H_AGE6FL <= -1 )
replace H_AGE7FL = . if (H_AGE7FL <= -1 )
replace H_AGE8FL = . if (H_AGE8FL <= -1 )
replace H_AGE9FL = . if (H_AGE9FL <= -1 )
replace O_SEX1FL = . if (O_SEX1FL <= -1 )
replace O_SEX2FL = . if (O_SEX2FL <= -1 )
replace O_SEX3FL = . if (O_SEX3FL <= -1 )
replace O_SEX4FL = . if (O_SEX4FL <= -1 )
replace O_RE1FL = . if (O_RE1FL <= -1 )
replace O_RE2FL = . if (O_RE2FL <= -1 )
replace O_RE3FL = . if (O_RE3FL <= -1 )
replace O_RE4FL = . if (O_RE4FL <= -1 )
replace O_RE5FL = . if (O_RE5FL <= -1 )
replace O_RE6FL = . if (O_RE6FL <= -1 )
replace O_RE7FL = . if (O_RE7FL <= -1 )
replace O_RE8FL = . if (O_RE8FL <= -1 )
replace O_AGE1FL = . if (O_AGE1FL <= -1 )
replace O_AGE2FL = . if (O_AGE2FL <= -1 )
replace O_AGE3FL = . if (O_AGE3FL <= -1 )
replace O_AGE4FL = . if (O_AGE4FL <= -1 )
replace O_AGE5FL = . if (O_AGE5FL <= -1 )
replace O_AGE6FL = . if (O_AGE6FL <= -1 )
replace O_AGE7FL = . if (O_AGE7FL <= -1 )
replace O_AGE8FL = . if (O_AGE8FL <= -1 )
replace O_AGE9FL = . if (O_AGE9FL <= -1 )
replace R_SEX1FL = . if (R_SEX1FL <= -1 )
replace R_SEX2FL = . if (R_SEX2FL <= -1 )
replace R_SEX3FL = . if (R_SEX3FL <= -1 )
replace R_SEX4FL = . if (R_SEX4FL <= -1 )
replace R_RE1FL = . if (R_RE1FL <= -1 )
replace R_RE2FL = . if (R_RE2FL <= -1 )
replace R_RE3FL = . if (R_RE3FL <= -1 )
replace R_RE4FL = . if (R_RE4FL <= -1 )
replace R_RE5FL = . if (R_RE5FL <= -1 )
replace R_RE6FL = . if (R_RE6FL <= -1 )
replace R_RE7FL = . if (R_RE7FL <= -1 )
replace R_RE8FL = . if (R_RE8FL <= -1 )
replace R_AGE1FL = . if (R_AGE1FL <= -1 )
replace R_AGE2FL = . if (R_AGE2FL <= -1 )
replace R_AGE3FL = . if (R_AGE3FL <= -1 )
replace R_AGE4FL = . if (R_AGE4FL <= -1 )
replace R_AGE5FL = . if (R_AGE5FL <= -1 )
replace R_AGE6FL = . if (R_AGE6FL <= -1 )
replace R_AGE7FL = . if (R_AGE7FL <= -1 )
replace R_AGE8FL = . if (R_AGE8FL <= -1 )
replace R_AGE9FL = . if (R_AGE9FL <= -1 )
replace TCLI1FL = . if (TCLI1FL <= -1 )
replace TCLI2FL = . if (TCLI2FL <= -1 )
replace TCLI3FL = . if (TCLI3FL <= -1 )
replace TCLI4FL = . if (TCLI4FL <= -1 )
replace TCLI5FL = . if (TCLI5FL <= -1 )
replace TCLI6FL = . if (TCLI6FL <= -1 )
replace TCLI7FL = . if (TCLI7FL <= -1 )
replace TCLIRCFL = . if (TCLIRCFL <= -1 )
replace TCLIOPFL = . if (TCLIOPFL <= -1 )
replace TCLIHIFL = . if (TCLIHIFL <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

